@@ -1,7 +1,10 @@
 /*
- * $Id: btree.h,v 1.3 2004/08/03 05:49:50 jklein Exp $
+ * $Id: btree.h,v 1.4 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: btree.h,v $
+ * Revision 1.4  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.3  2004/08/03 05:49:50  jklein
  * Add sxtable_t structure.
  *
@@ -22,9 +25,9 @@
 #ifndef _SCALL_BTREE_H_
 #define _SCALL_BTREE_H_
 
-#include "scale/commons.h"
-#include "scale/iterator.h"
-#include "scale/xtable.h"
+#include <scale/commons.h>
+#include <scale/iterator.h>
+#include <scale/xtable.h>
 
 
 typedef struct _sc_btree sbtree_t;
@@ -50,8 +53,8 @@ sbtree_t *		s_btree_alloc(sc_compf_t compare);
 void			s_btree_free(sbtree_t *btree);
 size_t			s_btree_size(const sbtree_t *btree);
 void			s_btree_add(sbtree_t *btree, spointer key, spointer conts);
-spointer		s_btree_get(const sbtree_t *btree, const spointer key);
-spointer		s_btree_remove(sbtree_t *btree, const spointer key);
+spointer		s_btree_get(const sbtree_t *btree, sconstpointer key);
+spointer		s_btree_remove(sbtree_t *btree, sconstpointer key);
 siterator_t *	s_btree_lfs_iterator(const sbtree_t *btree);
 
 sxtable_t *		s_btree_attach_xtable(sbtree_t *btree);
