@@ -1,7 +1,10 @@
 /*
- * $Id: commons.h,v 1.6 2004/06/28 09:51:09 jklein Exp $
+ * $Id: commons.h,v 1.7 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: commons.h,v $
+ * Revision 1.7  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.6  2004/06/28 09:51:09  jklein
  * interface was changed in scale/iterator.h
  *
@@ -37,9 +40,8 @@
 #ifndef _SCALE_COMMONS_H_
 #define _SCALE_COMMONS_H_
 
-#include "scale/config.h"
 #include <stdlib.h>
-
+#include <scale/config.h>
 
 #if HAVE_STRING_H
 #  include <string.h>
@@ -50,6 +52,8 @@
 
 /** all of primitive types for SC libraries. */
 typedef void * spointer;
+typedef const void * sconstpointer;
+
 
 #if HAVE_STDBOOL_H
 enum {
@@ -108,22 +112,22 @@ typedef double  sdouble;
  * $BJV$jCM$O(Bp1$B$NJ}$,Bg$-$$$H$-$O@5$N?t!"Ey$7$$$H$-$O(B0$B!"(Bp2$B$NJ}$,Bg$-$$$H$-$O(B
  * $BIi$N?t$rJV$7$^$9!#(B
  */
-typedef sint8 (*sc_compf_t)(const spointer p1, const spointer p2);
+typedef sint8 (*sc_compf_t)(sconstpointer p1, sconstpointer p2);
 
 
 /** (char *)$B$I$&$7$NHf3S$r9T$J$&!#(B */
-sint8 s_string_compare(const spointer, const spointer);
+sint8 s_string_compare(sconstpointer, sconstpointer);
 
 /** (char *)$B$I$&$7$NHf3S$r9T$J$&$,!"JV$jCM$ODL>o$N5U$K$J$k!#(B */
-sint8 s_string_rcompare(const spointer, const spointer);
+sint8 s_string_rcompare(sconstpointer, sconstpointer);
 
 /** sbuffer_t$B$I$&$7$NHf3S$r9T$J$&!#(B */
-sint8 s_buffer_compare(const spointer, const spointer);
+sint8 s_buffer_compare(sconstpointer, sconstpointer);
 
 /** sbuffer_t$B$I$&$7$NHf3S$r9T$J$&$,!"JV$jCM$O5U$K$J$k!#(B */
-sint8 s_buffer_rcompare(const spointer, const spointer);
+sint8 s_buffer_rcompare(sconstpointer, sconstpointer);
 
 /** $B%]%$%s%?$I$&$7$NHf3S$r9T$J$&!#(B */
-sint8 s_pointer_compare(const spointer, const spointer);
+sint8 s_pointer_compare(sconstpointer, sconstpointer);
 
 #endif /* _SCALE_COMMONS_H_ */
