@@ -4,10 +4,10 @@
 #define SCALE_GRAPHVIZ_H
 
 
-#include "scale/commons.h"
-#include "scale/heap.h"
-#include "scale/buffer.h"
-#include "scale/btree.h"
+#include <scale/commons.h>
+#include <scale/heap.h>
+#include <scale/buffer.h>
+#include <scale/btree.h>
 
 
 sbuffer_t *s_heap_graphviz(sheap_t *heap);
