@@ -1,7 +1,10 @@
 /*
- * $Id: hash.h,v 1.5 2004/08/03 05:49:50 jklein Exp $
+ * $Id: hash.h,v 1.6 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: hash.h,v $
+ * Revision 1.6  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.5  2004/08/03 05:49:50  jklein
  * Add sxtable_t structure.
  *
@@ -29,9 +32,9 @@
 #define _S_HASH_H_
 
 
-#include "scale/commons.h"
-#include "scale/iterator.h"
-#include "scale/xtable.h"
+#include <scale/commons.h>
+#include <scale/iterator.h>
+#include <scale/xtable.h>
 
 
 /*
@@ -41,15 +44,15 @@
 #define DEFAULT_HASH_SIZE 1021
 
 /** $B%O%C%7%e4X?t(B */
-typedef unsigned int (*hashfunc_t)(const spointer, size_t);
+typedef unsigned int (*hashfunc_t)(sconstpointer, size_t);
 typedef struct _sc_hash_table shash_t;
 
 
 shash_t *		s_hash_alloc(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf);
 void			s_hash_free(shash_t *htable);
-spointer		s_hash_get(shash_t *htable, const spointer key);
+spointer		s_hash_get(shash_t *htable, sconstpointer key);
 void			s_hash_put(shash_t *htable, spointer key, spointer contents);
-void			s_hash_remove(shash_t *htable, const spointer key);
+void			s_hash_remove(shash_t *htable, sconstpointer key);
 size_t			s_hash_size(shash_t *htable);
 void			s_hash_clear(shash_t *htable);
 
@@ -63,7 +66,7 @@ sxtable_t *s_hash_xtable(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf);
 sxtable_t *s_hash_attach_xtable(shash_t *hash);
 
 /* use this function for hashfunc_t. */
-unsigned int	s_string_hashfunc(const spointer key, size_t hashsize);
+unsigned int	s_string_hashfunc(sconstpointer key, size_t hashsize);
 
 
 #endif /* _S_HASH_H_ */
