@@ -1,7 +1,10 @@
 /*
- * $Id: iterator.h,v 1.3 2004/06/28 09:51:09 jklein Exp $
+ * $Id: iterator.h,v 1.4 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: iterator.h,v $
+ * Revision 1.4  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.3  2004/06/28 09:51:09  jklein
  * interface was changed in scale/iterator.h
  *
@@ -37,7 +40,7 @@
 #ifndef _SCALE_ITERATOR_H_
 #define _SCALE_ITERATOR_H_
 
-#include "scale/commons.h"
+#include <scale/commons.h>
 
 /** ƥ졼֥ */
 typedef struct _sc_iterator siterator_t;
