@@ -1,7 +1,10 @@
 /*
- * $Id: list.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
+ * $Id: list.h,v 1.8 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: list.h,v $
+ * Revision 1.8  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.7  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -44,9 +47,9 @@
 #ifndef _SCALE_LIST_H_
 #define _SCALE_LIST_H_
 
-#include "scale/commons.h"
-#include "scale/iterator.h"
-#include "scale/xarray.h"
+#include <scale/commons.h>
+#include <scale/iterator.h>
+#include <scale/xarray.h>
 
 /** $B%j%s%/%j%9%H!&%*%V%8%'%/%H(B*/
 typedef struct _sc_linklist slist_t;
@@ -78,8 +81,8 @@ struct _sc_linklist_node {
 slist_t *		s_list_alloc();
 void			s_list_free(slist_t *);
 size_t			s_list_size(slist_t *);
-void			s_list_insert_at(slist_t *, suint, const spointer);
-void 			s_list_add(slist_t *, const spointer);
+void			s_list_insert_at(slist_t *, suint, spointer);
+void 			s_list_add(slist_t *, spointer);
 spointer		s_list_get(slist_t *, suint);
 spointer		s_list_remove(slist_t *, suint);
 sint32			s_list_find(slist_t *, sc_compf_t, spointer);
