@@ -1,7 +1,10 @@
 /**
- * $Id: queue.h,v 1.3 2004/06/26 06:58:13 jklein Exp $
+ * $Id: queue.h,v 1.4 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: queue.h,v $
+ * Revision 1.4  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.3  2004/06/26 06:58:13  jklein
  * small fix in each header files.
  *
@@ -14,8 +17,8 @@
 #ifndef _SCALE_QUEUE_H_
 #define _SCALE_QUEUE_H_
 
-#include "scale/commons.h"
-#include "scale/list.h"
+#include <scale/commons.h>
+#include <scale/list.h>
 
 
 typedef slist_t squeue_t;
