@@ -1,7 +1,10 @@
 /**
- * $Id: scaleio.h,v 1.3 2004/07/09 09:43:58 jklein Exp $
+ * $Id: scaleio.h,v 1.4 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: scaleio.h,v $
+ * Revision 1.4  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.3  2004/07/09 09:43:58  jklein
  * few small changes.
  *
@@ -21,12 +24,10 @@
 #include <stdarg.h>
 #include <sys/param.h>
 
-#include "scale/commons.h"
-#include "scale/buffer.h"
+#include <scale/commons.h>
+#include <scale/buffer.h>
 
 
-typedef struct _sc_file sfile_t;
-
 int		s_writef(int fd, const char *fmt, ...);
 int		s_vwritef(int fd, const char *fmt, va_list ap);
 size_t	s_fullwrite(int fd, const void *buf, size_t count);
