@@ -1,7 +1,13 @@
 /*
- * $Id: stack.h,v 1.7 2004/07/22 17:27:56 jklein Exp $
+ * $Id: stack.h,v 1.9 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: stack.h,v $
+ * Revision 1.9  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
+ * Revision 1.8  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.7  2004/07/22 17:27:56  jklein
  * few changes in stack.h
  *
@@ -31,8 +37,8 @@
 #ifndef _SCALE_STACK_H_
 #define _SCALE_STACK_H_
 
-#include "scale/commons.h"
-#include "scale/vector.h"
+#include <scale/commons.h>
+#include <scale/vector.h>
 
 typedef svector_t sstack_t;
 
@@ -44,6 +50,7 @@ typedef svector_t sstack_t;
 #define s_stack_push(s, c)		s_vector_add((svector_t *)(s), c)
 #define s_stack_find(s, c, f)	s_vector_find((svector_t *)(s), c, f)
 #define s_stack_get(s, i)		s_vector_get((svector_t *)(s), i)
+#define s_stack_resize(s)		s_vector_resize((svector_t *)(s))
 
 spointer		s_stack_peek(sstack_t *);
 spointer		s_stack_pop(sstack_t *);
