@@ -1,7 +1,13 @@
 /*
- * $Id: vector.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
+ * $Id: vector.h,v 1.9 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: vector.h,v $
+ * Revision 1.9  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
+ * Revision 1.8  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.7  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -41,9 +47,9 @@
 #ifndef _SCALE_VECTOR_H_
 #define _SCALE_VECTOR_H_
 
-#include "scale/commons.h"
-#include "scale/iterator.h"
-#include "scale/xarray.h"
+#include <scale/commons.h>
+#include <scale/iterator.h>
+#include <scale/xarray.h>
 
 
 typedef struct _vector svector_t;
@@ -60,13 +66,14 @@ svector_t *		s_vector_alloc(void);
 svector_t *		s_vector_allocn(size_t);
 void			s_vector_free(svector_t *);
 size_t			s_vector_size(svector_t *);
-void			s_vector_insert_at(svector_t *, suint, const spointer);
-void			s_vector_add(svector_t *, const spointer);
+void			s_vector_insert_at(svector_t *, suint, spointer);
+void			s_vector_add(svector_t *, spointer);
 spointer		s_vector_get(svector_t *, suint);
 spointer		s_vector_remove(svector_t *, suint);
 sint32			s_vector_find(svector_t *, sc_compf_t, spointer);
 sboolean		s_vector_join(svector_t *, svector_t *);
 void			s_vector_sort(svector_t *, sc_compf_t);
+void			s_vector_resize(svector_t *);
 
 siterator_t *	s_vector_iterator(svector_t *);
 sxarray_t *		s_vector_xarray(void);
