@@ -1,7 +1,13 @@
 /*
- * $Id: xarray.h,v 1.6 2004/08/05 13:54:30 jklein Exp $
+ * $Id: xarray.h,v 1.8 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: xarray.h,v $
+ * Revision 1.8  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
+ * Revision 1.7  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.6  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -37,8 +43,8 @@
 #ifndef _SCALE_XARRAY_H_
 #define _SCALE_XARRAY_H_
 
-#include "scale/commons.h"
-#include "scale/iterator.h"
+#include <scale/commons.h>
+#include <scale/iterator.h>
 
 
 /** $BCj>]2DJQD9G[Ns%*%V%8%'%/%H(B */
@@ -55,23 +61,28 @@ typedef struct _sc_xarray sxarray_t;
 #define s_xarray_iterator(xa) (xa->iterator(xa))
 #define s_xarray_sort(xa, cmpf) (xa->sort(xa, cmpf))
 #define s_xarray_join(xd, xs) (xd->join(xd, xs))
+#define s_xarray_resize(xa) (xa->resize(xa))
 
 
 /**
  * sxarray_t$B9=B$BN!#3F<o2DJQD9G[Ns$N6&DL%$%s%?!<%U%'!<%9$H$J$k!#(B
+ * $B$3$N9=B$BN$K4^$^$l$k4X?t$rD>@\8F$S=P$7$F$bLdBjL5$$$,!"2DFI@-$N0Y$K$b(B
+ * $B@lMQ$KMQ0U$5$l$F$$$k(Bs_xarray_XXXX$B$H$$$&9=B$BN$rDL$7$F%"%/%;%9$9$k(B
+ * $BJ}$,NI$$!#(B
  */
 struct _sc_xarray {
 	/* sxarray interfaces */
 	void		(*free)(sxarray_t *);
 	size_t		(*size)(sxarray_t *);
-	void		(*insert_at)(sxarray_t *, suint, spointer);
+	void		(*insert_at)(sxarray_t *, size_t, spointer);
 	void		(*add)(sxarray_t *, spointer); 
-	spointer	(*get)(sxarray_t *, suint) ;
-	spointer	(*remove)(sxarray_t *, suint);
+	spointer	(*get)(sxarray_t *, size_t) ;
+	spointer	(*remove)(sxarray_t *, size_t);
 	sint32		(*find)(sxarray_t *, sc_compf_t, spointer);
 	siterator_t * (*iterator)(sxarray_t *);
 	void		(*sort)(sxarray_t *, sc_compf_t);
 	void		(*join)(sxarray_t *, sxarray_t *);
+	void		(*resize)(sxarray_t *);
 
 	/* -- CAUTION ---------------------
 	   Do never touch thing below here.
