@@ -1,6 +1,9 @@
-/* $Id: xtable.h,v 1.1 2004/08/03 05:49:50 jklein Exp $
+/* $Id: xtable.h,v 1.2 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: xtable.h,v $
+ * Revision 1.2  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.1  2004/08/03 05:49:50  jklein
  * Add sxtable_t structure.
  *
@@ -9,7 +12,7 @@
 #ifndef _SCALE_XTABLE_H_
 #define _SCALE_XTABLE_H_
 
-#include "scale/commons.h"
+#include <scale/commons.h>
 
 
 #define s_xtable_free(xt) (xt->free(xt))
@@ -29,8 +32,8 @@ struct sc_xtable_s {
 	void		(*free)(sxtable_t *);
 	size_t		(*size)(const sxtable_t *);
 	void		(*put)(sxtable_t *, spointer key, spointer contents);
-	spointer	(*get)(const sxtable_t *, const spointer key);
-	void		(*remove)(sxtable_t *, const spointer key);
+	spointer	(*get)(const sxtable_t *, sconstpointer key);
+	void		(*remove)(sxtable_t *, sconstpointer key);
 	siterator_t *(*keys)(const sxtable_t *);
 
 
