@@ -1,7 +1,8 @@
 
-#include "scale/btree.h"
-#include "scale/alloc.h"
 #include <stdio.h>
+#include <scale/btree.h>
+#include <scale/alloc.h>
+
 
 static sbtree_node_t *
 _s_node_alloc(spointer key, spointer contents)
@@ -91,12 +92,12 @@ s_btree_add(sbtree_t *btree, spointer key, spointer conts)
 
 
 spointer	
-s_btree_get(const sbtree_t *btree, const spointer key)
+s_btree_get(const sbtree_t *btree, sconstpointer key)
 {
 	sint cmp;
 	sbtree_node_t *node;
 
-	btree->end->key = key;
+	btree->end->key = (spointer)key;
 	node = btree->head->rnode;
 	
 	while ((cmp = btree->compare(key, node->key)) != 0) {
@@ -108,14 +109,14 @@ s_btree_get(const sbtree_t *btree, const spointer key)
 
 
 spointer	
-s_btree_remove(sbtree_t *btree, const spointer key)
+s_btree_remove(sbtree_t *btree, sconstpointer key)
 {
 	sint cmp;
 	sbtree_node_t *pnode, *cnode, *tnode;
 	spointer contents;
 	sboolean save_right;
 
-	btree->end->key = key;
+	btree->end->key = (spointer)key;
 	pnode = btree->head;
 	cnode = btree->head->rnode;
 	save_right = true;
@@ -294,14 +295,14 @@ _s_btree_xtable_put(sxtable_t *xt, spointer key, spointer contents)
 
 
 static spointer
-_s_btree_xtable_get(const sxtable_t *xt, const spointer key)
+_s_btree_xtable_get(const sxtable_t *xt, sconstpointer key)
 {
 	return s_btree_get(GET_BTREE(xt), key);
 }
 
 
 static void
-_s_btree_xtable_remove(sxtable_t *xt, const spointer key)
+_s_btree_xtable_remove(sxtable_t *xt, sconstpointer key)
 {
 	s_btree_remove(GET_BTREE(xt), key);
 }
