@@ -1,7 +1,10 @@
 /**
- * $Id: sc_commons.c,v 1.7 2004/08/02 16:38:01 jklein Exp $
+ * $Id: sc_commons.c,v 1.8 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_commons.c,v $
+ * Revision 1.8  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.7  2004/08/02 16:38:01  jklein
  * Fixed bug in the btree.c
  *
@@ -21,12 +24,12 @@
 
 
 #include <string.h>
-#include "scale/commons.h"
-#include "scale/buffer.h"
+#include <scale/commons.h>
+#include <scale/buffer.h>
 
 
 sint8
-s_string_compare(const spointer p1, const spointer p2)
+s_string_compare(sconstpointer p1, sconstpointer p2)
 {
 	const char *str1 = (char *)p1;
 	const char *str2 = (char *)p2;
@@ -41,14 +44,14 @@ s_string_compare(const spointer p1, const spointer p2)
 
 
 sint8
-s_string_rcompare(const spointer p1, const spointer p2)
+s_string_rcompare(sconstpointer p1, sconstpointer p2)
 {
 	return s_string_compare(p2, p1);
 }
 
 
 sint8
-s_buffer_compare(const spointer p1, const spointer p2)
+s_buffer_compare(sconstpointer p1, sconstpointer p2)
 {
 	const sbuffer_t *b1 = (sbuffer_t *)p1;
 	const sbuffer_t *b2 = (sbuffer_t *)p2;
@@ -63,14 +66,14 @@ s_buffer_compare(const spointer p1, const spointer p2)
 
 
 sint8
-s_buffer_rcompare(const spointer p1, const spointer p2)
+s_buffer_rcompare(sconstpointer p1, sconstpointer p2)
 {
 	return s_buffer_compare(p2, p1);
 }
 
 
 sint8
-s_pointer_compare(const spointer p1, const spointer p2)
+s_pointer_compare(sconstpointer p1, sconstpointer p2)
 {
 	return (long)p1 - (long)p2;
 }
