@@ -1,7 +1,10 @@
 /**
- * $Id: sc_hash.c,v 1.7 2004/08/05 13:54:30 jklein Exp $
+ * $Id: sc_hash.c,v 1.8 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_hash.c,v $
+ * Revision 1.8  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.7  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -20,9 +23,9 @@
  */
 
 
-#include "scale/hash.h"
-#include "scale/alloc.h"
-#include "scale/xtable.h"
+#include <scale/hash.h>
+#include <scale/alloc.h>
+#include <scale/xtable.h>
 
 
 typedef struct _sc_hash_elt shash_elt_t;
@@ -45,7 +48,7 @@ struct _sc_hash_table {
 
 static void
 _s_hash_remove_by_key(shash_t *htable,
-					  const spointer key,
+					  sconstpointer key,
 					  unsigned int hashkey)
 {
 	shash_elt_t *elt = NULL, *prev = NULL;
@@ -84,7 +87,7 @@ s_hash_alloc(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf)
 
 
 spointer
-s_hash_get(shash_t *htable, const spointer key)
+s_hash_get(shash_t *htable, sconstpointer key)
 {
 	unsigned int hashkey;
 	shash_elt_t *elt;
@@ -127,7 +130,7 @@ s_hash_put(shash_t *htable, spointer key, spointer obj)
  * It only takes out from a hash-table.
  * So, you have to free it in you own reponsibility. */
 void
-s_hash_remove(shash_t *htable, const spointer key)
+s_hash_remove(shash_t *htable, sconstpointer key)
 {
 	_s_hash_remove_by_key(htable, key, htable->hash(key, htable->hashsize));
 }
@@ -169,12 +172,12 @@ s_hash_clear(shash_t *htable)
 
 /* 
  * Alfred V. Aho, Ravi Sethi, Jeffrey D. Ullman 
- * ĸإѥ飲 ˡġ
- * Ҽڡ
- * ºݤ˼¸ơХ󥹤ɤϥåͤ뤳Ȥǧ
+ * Ēؒђ钣 ˡĒ뒡
+ * 蒤Ғڒ
+ * ݒ˒ƒВ钥󒥹ΒɒϒÒ͒钤쒤뒤ȒΒǧ
  */
 unsigned int
-s_string_hashfunc(const spointer key, size_t hashsize)
+s_string_hashfunc(sconstpointer key, size_t hashsize)
 {
 	unsigned int h, g;
 	const unsigned char *p;
@@ -301,14 +304,14 @@ _s_hash_xtable_put(sxtable_t *xt, spointer key, spointer contents)
 
 
 static spointer
-_s_hash_xtable_get(const sxtable_t *xt, const spointer key)
+_s_hash_xtable_get(const sxtable_t *xt, sconstpointer key)
 {
 	return s_hash_get(GET_HASH(xt), key);
 }
 
 
 static void
-_s_hash_xtable_remove(sxtable_t *xt, const spointer key)
+_s_hash_xtable_remove(sxtable_t *xt, sconstpointer key)
 {
 	s_hash_remove(GET_HASH(xt), key);
 }
