@@ -1,6 +1,6 @@
 
-#include "scale/heap.h"
-#include "scale/alloc.h"
+#include <scale/heap.h>
+#include <scale/alloc.h>
 
 
 #define DEF_HEAP_SIZE 64
@@ -9,9 +9,6 @@
 static void
 _s_heap_grouth(sheap_t *heap, size_t tsize)
 {
-	if (heap->memsize >= tsize)
-		return; /* nothiong to do. */
-
 	heap->array = (spointer *)s_creallocn(heap->array,
 										  sizeof(spointer) * heap->memsize,
 										  sizeof(spointer) * tsize);
@@ -80,7 +77,7 @@ s_heap_push(sheap_t *heap, spointer contents)
 	++heap->next_index;
 }
 
-#include <stdio.h>
+
 spointer
 s_heap_pop(sheap_t *heap)
 {
@@ -151,7 +148,10 @@ s_heap_size(sheap_t *heap)
 spointer
 s_heap_get(sheap_t *heap, size_t ind)
 {
-	/* remember array index in heap-array is starting from 1. */
+	/* Remember array index in heap-array is starting from 1.
+	   And since a client program doesn't know this rule, if the contents
+	   of an index 0 is requested, we have to return the contents by the
+	   index 1. */
 	++ind;
 
 	if (ind >= s_heap_size(heap))
@@ -159,3 +159,10 @@ s_heap_get(sheap_t *heap, size_t ind)
 	else
 		return heap->array[ind];
 }
+
+
+void
+s_heap_resize(sheap_t *heap)
+{
+	_s_heap_grouth(heap, heap->count+1);
+}
