@@ -1,7 +1,13 @@
 /**
- * $Id: sc_list.c,v 1.9 2004/08/05 13:54:30 jklein Exp $
+ * $Id: sc_list.c,v 1.11 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_list.c,v $
+ * Revision 1.11  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
+ * Revision 1.10  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.9  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -27,8 +33,8 @@
 
 
 #include <stdio.h>
-#include "scale/list.h"
-#include "scale/alloc.h"
+#include <scale/list.h>
+#include <scale/alloc.h>
 
 
 #define _CLEAN_HEAD_TAIL(__list) \
@@ -143,7 +149,7 @@ s_list_size(slist_t *list)
 
 
 void
-s_list_insert_at(slist_t *list, suint idx, const spointer contents)
+s_list_insert_at(slist_t *list, suint idx, spointer contents)
 {
 	slist_node_t *node;
 	slist_node_t *newnode;
@@ -165,7 +171,7 @@ s_list_insert_at(slist_t *list, suint idx, const spointer contents)
 
 
 void
-s_list_add(slist_t *list, const spointer contents)
+s_list_add(slist_t *list, spointer contents)
 {
 	s_list_insert_at(list, list->count, contents);
 }
@@ -457,7 +463,7 @@ _s_list_xarr_size(sxarray_t *xarr)
 
 
 static void
-_s_list_xarr_insert_at(sxarray_t *xarr, suint idx, spointer contents)
+_s_list_xarr_insert_at(sxarray_t *xarr, size_t idx, spointer contents)
 {
 	s_list_insert_at(__XARR_GET_LIST(xarr), idx, contents);
 }
@@ -532,6 +538,11 @@ _s_list_xarr_join(sxarray_t *dest, sxarray_t *src)
 }
 
 
+static void
+_s_list_xarr_resize(sxarray_t *xarr)
+{
+	/* nothing to do */
+}
 
 
 sxarray_t *
@@ -560,7 +571,8 @@ s_list_attach_xarray(slist_t *list)
 	xarr->iterator = _s_list_xarr_iterator;
 	xarr->sort     = _s_list_xarr_sort;
 	xarr->join	   = _s_list_xarr_join;
-	xarr->insert_at	   = _s_list_xarr_insert_at;
+	xarr->insert_at	= _s_list_xarr_insert_at;
+	xarr->resize	= _s_list_xarr_resize;
 
 	xarr->is_origin = false;
 	
