@@ -1,7 +1,10 @@
 /**
- * $Id: sc_queue.c,v 1.4 2004/08/05 13:54:30 jklein Exp $
+ * $Id: sc_queue.c,v 1.5 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_queue.c,v $
+ * Revision 1.5  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.4  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -11,7 +14,7 @@
  */
 
 
-#include "scale/queue.h"
+#include <scale/queue.h>
 
 
 spointer
