@@ -1,14 +1,17 @@
 /**
- * $Id: sc_stack.c,v 1.3 2004/06/21 16:44:17 jklein Exp $
+ * $Id: sc_stack.c,v 1.4 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_stack.c,v $
+ * Revision 1.4  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
  * Revision 1.3  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
  */
 
 
-#include "scale/stack.h"
+#include <scale/stack.h>
 
 
 spointer
