@@ -1,7 +1,13 @@
 /*
- * $Id: sc_vector.c,v 1.13 2004/08/05 13:54:30 jklein Exp $
+ * $Id: sc_vector.c,v 1.15 2004/09/04 07:08:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.15  2004/09/04 07:08:01  jklein
+ * fixed "const spointer" to "sconstpointer".
+ *
+ * Revision 1.14  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.13  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -38,8 +44,8 @@
  */
 
 
-#include "scale/alloc.h"
-#include "scale/vector.h"
+#include <scale/alloc.h>
+#include <scale/vector.h>
 
 
 #define DEF_VECTOR_SIZE 64
@@ -49,9 +55,6 @@
 void
 _s_vector_grouth(svector_t *vect, size_t tsize)
 {
-	if (vect->memsize >= tsize)
-		return; /* nothiong to do. */
-
 	vect->array = (spointer *)s_reallocn(vect->array,
 										 sizeof(spointer) * vect->memsize,
 										 sizeof(spointer) * tsize);
@@ -99,7 +102,7 @@ s_vector_size(svector_t *vect)
 
 
 void
-s_vector_insert_at(svector_t *vect, suint idx, const spointer contents)
+s_vector_insert_at(svector_t *vect, suint idx, spointer contents)
 {
 	register int i;
 
@@ -110,13 +113,12 @@ s_vector_insert_at(svector_t *vect, suint idx, const spointer contents)
 		vect->array[i] = vect->array[i-1];
 
 	vect->array[idx] = contents;
-
  	++vect->count; 
 }
 
 
 void
-s_vector_add(svector_t *vect, const spointer contents) 
+s_vector_add(svector_t *vect, spointer contents) 
 {
 	s_vector_insert_at(vect, vect->count, contents);
 }
@@ -136,16 +138,15 @@ spointer
 s_vector_remove(svector_t *vect, suint idx) 
 {
 	spointer contents;
-	sint i;
+	suint i;
 
 	if (vect->count <= idx)
 		return NULL;
 
 	contents = vect->array[idx];
-	vect->array[idx] = NULL;
 
 	/* need to slide all contents after 'idx'. */
-	for (i=idx; i<vect->count-1; i++) {
+	for (i=idx; i<vect->count-1; ++i) {
 		vect->array[i] = vect->array[i+1];
 	}
 	vect->array[vect->count-1] = NULL;
@@ -158,9 +159,9 @@ s_vector_remove(svector_t *vect, suint idx)
 sint32			
 s_vector_find(svector_t *vect, sc_compf_t compare, spointer contents) 
 {
-	sint i;
+	suint i;
 
-	for (i=0; i<vect->count; i++) {
+	for (i=0; i<vect->count; ++i) {
 		if (compare(vect->array[i], contents) == 0)
 			return i;
 	}
@@ -172,14 +173,14 @@ sboolean
 s_vector_join(svector_t *dst, svector_t *src) 
 {
 	size_t newsize;
-	sint i;
+	suint i;
 
 	newsize = dst->count + src->count;
 
 	if (dst->memsize < newsize)
 		_s_vector_grouth(dst, newsize);
 
-	for (i=0; i<src->count; i++) {
+	for (i=0; i<src->count; ++i) {
 		dst->array[dst->count++] = src->array[i];
 	}
 
@@ -201,8 +202,8 @@ _s_vector_qsort(spointer list[], int low, int high, sc_compf_t cmpf)
 		int j = high;
 
 		while (i <= j) {
-			while (cmpf(list[++i], x) < 0) ;
-			while (j > i && cmpf(list[--j], x) > 0) ;
+			while (cmpf(list[++i], x) < 0) /* none */ ;
+			while (j > i && cmpf(list[--j], x) > 0) /* none */ ;
 
 			if (i >= j)
 				break;
@@ -230,6 +231,12 @@ s_vector_sort(svector_t *vect, sc_compf_t cmpf)
 }
 
 
+void
+s_vector_resize(svector_t *vect)
+{
+	_s_vector_grouth(vect, s_vector_size(vect));
+}
+
 
 /***************************************************************************
  * These functions are for siterator_t interface.
@@ -315,7 +322,7 @@ _s_vect_xarr_size(sxarray_t *xarr)
 
 
 static void
-_s_vect_xarr_insert_at(sxarray_t *xarr, suint idx, spointer contents)
+_s_vect_xarr_insert_at(sxarray_t *xarr, size_t idx, spointer contents)
 {
 	s_vector_insert_at(__XARR_GET_VECT(xarr), idx, contents);
 }
@@ -381,6 +388,13 @@ _s_vect_xarr_join(sxarray_t *dest, sxarray_t *src)
 }
 
 
+static void
+_s_vect_xarr_resize(sxarray_t *xarr)
+{
+	s_vector_resize(__XARR_GET_VECT(xarr));
+}
+
+
 sxarray_t *
 s_vector_xarray(void)
 {
@@ -418,6 +432,7 @@ s_vector_attach_xarray(svector_t *vect)
 	xarr->sort     = _s_vect_xarr_sort;
 	xarr->join	   = _s_vect_xarr_join;
 	xarr->insert_at = _s_vect_xarr_insert_at;
+	xarr->resize	= _s_vect_xarr_resize;
 	
 	xarr->is_origin = false;
 
