@@ -1,7 +1,10 @@
 /**
- * $Id: tester.c,v 1.14 2004/08/05 13:54:30 jklein Exp $
+ * $Id: tester.c,v 1.15 2004/08/08 07:14:45 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.15  2004/08/08 07:14:45  jklein
+ * Added 'resize()' function to array objects.
+ *
  * Revision 1.14  2004/08/05 13:54:30  jklein
  * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
  *
@@ -225,6 +228,7 @@ sxarray_tester(sxarray_t *xarr)
 	s_xarray_add(xarr, "C");
 	s_xarray_add(xarr, "A");
 
+	s_xarray_resize(xarr);
 	s_xarray_sort(xarr, s_string_compare);
 
 	assert(s_xarray_size(xarr) == 3);
@@ -239,6 +243,8 @@ sxarray_tester(sxarray_t *xarr)
 	assert(strcmp(s_xarray_remove(xarr, 0), "C") == 0);
 	assert(s_xarray_size(xarr) == 0);
 
+	s_xarray_resize(xarr);
+
 	/* join test */
 	vx = s_vector_xarray();
 	lx = s_list_xarray();
@@ -716,6 +722,8 @@ test_heap()
 	s_heap_push(heap, "F");
 	s_heap_push(heap, "E");
 
+	s_heap_resize(heap);
+
 	assert(s_heap_size(heap) == 6);
 
 /* 	sbuffer_t *gbuf = s_heap_graphviz(heap); */
@@ -727,7 +735,9 @@ test_heap()
 	assert(strcmp(s_heap_pop(heap), "D") == 0);
 	assert(strcmp(s_heap_pop(heap), "C") == 0);
 	assert(strcmp(s_heap_pop(heap), "B") == 0);
-	
+
+	s_heap_resize(heap);
+
 	assert(strcmp(s_heap_peek(heap), "A") == 0);
 	assert(s_heap_size(heap) == 1);
 	assert(strcmp(s_heap_pop(heap), "A") == 0);
